isPresent method

  1. @override
Future<bool> isPresent()

Returns true if there is a geocoder implementation present that may return results. If true, there is still no guarantee that any individual geocoding attempt will succeed.

This method is only implemented on Android, calling this on iOS always returns true.

Implementation

@override
Future<bool> isPresent() async {
  try {
    final isPresent = await _channel.invokeMethod(
      'isPresent',
    );
    return isPresent;
  } on PlatformException catch (e) {
    _handlePlatformException(e);
    rethrow;
  }
}